#!/usr/bin/python
# -*- encoding: utf-8; py-indent-offset: 4 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2018-03-12
#
# Check Point Eventia metrics plugins
# checkpoint_eva
# checkpoint_eva_db
# checkpoint_eva_jobs
#

##############################################################################
#
# define units for perfdata
#
##############################################################################

##############################################################################
#
# define metrics for perfdata
#
##############################################################################

metric_info['checkpoint_eva_newevents'] = {
    'title': _('New events'),
    'unit': '1/s',
    'color': '11/a',
}
metric_info['checkpoint_eva_updates'] = {
    'title': _('Updates'),
    'unit': '1/s',
    'color': '21/a',
}
metric_info['checkpoint_eva_numprocessedlogs_sec'] = {
    'title': _('Processed logs'),
    'unit': '1/s',
    'color': '26/a',
}
metric_info['checkpoint_eva_cu_events'] = {
    'title': _('Events'),
    'unit': '1/s',
    'color': '11/a',
}
metric_info['checkpoint_eva_cu_uptime'] = {
    'title': _('Uptime'),
    'unit': 's',
    'color': '21/a',
}
metric_info['checkpoint_eva_db_db_disk_space'] = {
    'title': _('Database disc space'),
    'unit': 'bytes',
    'color': '21/a',
}
metric_info['checkpoint_eva_db_db_capacity'] = {
    'title': _('Database capacity'),
    'unit': 'bytes',
    'color': '31/a',
}
metric_info['checkpoint_eva_db_db_size'] = {
    'title': _('Database size'),
    'unit': 'bytes',
    'color': '11/a',
}
metric_info['checkpoint_eva_db_events_in_db'] = {
    'title': _('Events in Database'),
    'unit': 'count',
    'color': '41/a',
}
metric_info['checkpoint_eva_db_disk_size'] = {
    'title': _('Disk Size'),
    'unit': 'bytes',
    'color': '42/a',
}
metric_info['checkpoint_eva_jobs_analyzed_log'] = {
    'title': _('Analyzed logs'),
    'unit': '1/s',
    'color': '11/a',
}
metric_info['checkpoint_eva_jobs_position_in_file'] = {
    'title': _('Position in file'),
    'unit': 'count',
    'color': '21/a',
}

##############################################################################
#
# map perfdata to metric
#
##############################################################################

check_metrics['check_mk-checkpoint_eva_status'] = {
    'newevents': {'name': 'checkpoint_eva_newevents', },
    'updates': {'name': 'checkpoint_eva_updates', },
}
check_metrics['check_mk-checkpoint_eva_cu_status'] = {
    'numprocessedlogs_sec': {'name': 'checkpoint_eva_numprocessedlogs_sec', },
}
check_metrics['check_mk-checkpoint_eva_cu'] = {
    'events': {'name': 'checkpoint_eva_cu_events', },
    'uptime': {'name': 'checkpoint_eva_cu_uptime', },
}
check_metrics['check_mk-checkpoint_eva_db'] = {
    'db_disk_space': {'name': 'checkpoint_eva_db_db_disk_space', },
    'db_capacity': {'name': 'checkpoint_eva_db_db_capacity', 'auto_graph': False},
    'db_size': {'name': 'checkpoint_eva_db_db_size', },
    'events_in_db': {'name': 'checkpoint_eva_db_events_in_db', },
    'disk_size': {'name': 'checkpoint_eva_db_disk_size', },
}
check_metrics['check_mk-checkpoint_eva_jobs'] = {
    'analyzed_logs': {'name': 'checkpoint_eva_jobs_analyzed_log', },
    'position_in_file': {'name': 'checkpoint_eva_jobs_position_in_file', },
}

##############################################################################
#
# how to graph perdata
#
##############################################################################

graph_info.append({
    'title': _('Check Point Eventia Status: Events/Updates'),
    'metrics': [
        ('checkpoint_eva_newevents', 'line'),
        ('checkpoint_eva_updates', '-line'),
    ],
})
graph_info.append({
    'title': _('Check Point Eventia correlation unit status'),
    'metrics': [
        ('checkpoint_eva_numprocessedlogs_sec', 'line'),
    ],
})

graph_info.append({
    'title': _('Check Point Eventia Database/Disk'),
    'metrics': [
        ('checkpoint_eva_db_db_size', 'stack'),
        ('checkpoint_eva_db_db_disk_space', 'stack'),
        # ('checkpoint_eva_db_db_capacity', 'stack'),
        ('checkpoint_eva_db_disk_size', 'line')
    ],
})
graph_info.append({
    'title': _('Check Point Eventia events in database'),
    'metrics': [
        ('checkpoint_eva_db_events_in_db', 'area'),
    ],
})
graph_info.append({
    'title': _('Check Point Eventia Job: Analyzed events'),
    'metrics': [
        ('checkpoint_eva_jobs_analyzed_log', 'line'),
    ],
})
graph_info.append({
    'title': _('Check Point Eventia Job: Position in file'),
    'metrics': [
        ('checkpoint_eva_jobs_position_in_file', 'line'),
    ],
})

##############################################################################
#
# define perf-o-meter
#
##############################################################################

perfometer_info.append(('stacked', [
    {
        'type': 'logarithmic',
        'metric': 'checkpoint_eva_newevents',
        'half_value': 1000.0,
        'exponent': 2,
    },
    {
        'type': 'logarithmic',
        'metric': 'checkpoint_eva_updates',
        'half_value': 1000.0,
        'exponent': 2,
    },
]))

perfometer_info.append(('stacked', [
    {
        'type': 'logarithmic',
        'metric': 'checkpoint_eva_cu_uptime',
        'half_value': 2592000.0,
        'exponent': 2,
    },
    {
        'type': 'linear',
        'segments': ['checkpoint_eva_cu_events'],
        'total': 100,
    }
]))

perfometer_info.append(('stacked', [
    {
        'type': 'logarithmic',
        'metric': 'checkpoint_eva_db_db_size',
        'half_value': 500000000.0,
        'exponent': 6,
    },
    {
        'type': 'logarithmic',
        'metric': 'checkpoint_eva_db_events_in_db',
        'half_value': 500000.0,
        'exponent': 2,
    },
]))
perfometer_info.append({
        'type': 'logarithmic',
        'metric': 'checkpoint_eva_jobs_analyzed_log',
        'half_value': 100.0,
        'exponent': 2,
})
perfometer_info.append({
        'type': 'logarithmic',
        'metric': 'checkpoint_eva_numprocessedlogs_sec',
        'half_value': 1000.0,
        'exponent': 2,
})